This function computes the elasticity of Gini index associated with a percentage change in the mean income (for each income source).
It provides a set of indicators :
income_source: Column indicating each income source passed into the function call.
Share: Column indicating the share of the income source to the total income.
Gini: Column showing the Gini index for each income source.
Gini_corr: Column showing the Gini correlation between the income source and the total income.
Elasticity: Column indicating the elasticity of Gini index associated with a percentage change in the mean income source.
Marginal_Impact: Column indicating the marginal impact of a change in the mean income source on the overall Gini index.
An object of class data.frame containing all the calculated indicators. The data.frame is grouped by the columns passed into .by argument.
Arguments
.data
A data frame, or data frame extension (e.g. a tibble)
...
One or more unquoted expressions separated by commas indicating income sources to consider in the decomposition. Variable names can be used as if they were positions in the data frame.
.by
A column to group the calculations by.
.wgt
an optional vector of weights to apply in computation. Should be NULL or a numeric vector.